@@ -5,21 +5,20 @@
 #include <aws/io/tls_channel_handler.h>
 
 #include <aws/common/clock.h>
+#include <aws/common/encoding.h>
 #include <aws/common/mutex.h>
-
+#include <aws/common/string.h>
+#include <aws/common/task_scheduler.h>
+#include <aws/common/thread.h>
 #include <aws/io/channel.h>
 #include <aws/io/event_loop.h>
 #include <aws/io/file_utils.h>
 #include <aws/io/logging.h>
+#include <aws/io/private/event_loop_impl.h>
 #include <aws/io/private/pki_utils.h>
 #include <aws/io/private/tls_channel_handler_shared.h>
 #include <aws/io/statistics.h>
 
-#include <aws/common/encoding.h>
-#include <aws/common/string.h>
-#include <aws/common/task_scheduler.h>
-#include <aws/common/thread.h>
-
 #include <s2n.h>
 #ifdef AWS_S2N_INSOURCE_PATH
 #    include <api/unstable/cleanup.h>
@@ -255,7 +254,7 @@ void aws_tls_init_static_state(struct aws_allocator *alloc) {
 void aws_tls_clean_up_static_state(void) {
     /* only clean up s2n if we were the ones that initialized it */
     if (!s_s2n_initialized_externally) {
-        s2n_cleanup();
+        s2n_cleanup_final();
     }
 }
 
@@ -269,10 +268,14 @@ bool aws_tls_is_cipher_pref_supported(enum aws_tls_cipher_pref cipher_pref) {
             return true;
             /* PQ Crypto no-ops on android for now */
 #ifndef ANDROID
-        case AWS_IO_TLS_CIPHER_PREF_PQ_TLSv1_0_2021_05:
+        case AWS_IO_TLS_CIPHER_PREF_PQ_TLSV1_2_2024_10:
+            return true;
+        case AWS_IO_TLS_CIPHER_PREF_PQ_DEFAULT:
             return true;
 #endif
 
+        case AWS_IO_TLS_CIPHER_PREF_TLSV1_2_2025_07:
+            return true;
         default:
             return false;
     }
@@ -1339,7 +1342,7 @@ static struct aws_channel_handler *s_new_tls_handler(
             (void *)&s2n_handler->handler,
             aws_string_c_str(options->alpn_list));
 
-        const char protocols_cpy[4][128];
+        const char protocols_cpy[4][128] = {{0}};
         AWS_ZERO_ARRAY(protocols_cpy);
         size_t protocols_size = 4;
         if (s_parse_protocol_preferences(options->alpn_list, protocols_cpy, &protocols_size)) {
@@ -1402,7 +1405,8 @@ struct aws_channel_handler *aws_tls_server_handler_new(
     return s_new_tls_handler(allocator, options, slot, S2N_SERVER);
 }
 
-static void s_s2n_ctx_destroy(struct s2n_ctx *s2n_ctx) {
+static void s_s2n_ctx_destroy(void *user_data) {
+    struct s2n_ctx *s2n_ctx = user_data;
     if (s2n_ctx != NULL) {
         if (s2n_ctx->s2n_config) {
             s2n_config_free(s2n_ctx->s2n_config);
@@ -1446,11 +1450,6 @@ static struct aws_tls_ctx *s_tls_ctx_new(
     struct aws_allocator *alloc,
     const struct aws_tls_ctx_options *options,
     s2n_mode mode) {
-    struct s2n_ctx *s2n_ctx = aws_mem_calloc(alloc, 1, sizeof(struct s2n_ctx));
-
-    if (!s2n_ctx) {
-        return NULL;
-    }
 
     if (!aws_tls_is_cipher_pref_supported(options->cipher_pref)) {
         aws_raise_error(AWS_IO_TLS_CIPHER_PREF_UNSUPPORTED);
@@ -1458,6 +1457,8 @@ static struct aws_tls_ctx *s_tls_ctx_new(
         return NULL;
     }
 
+    struct s2n_ctx *s2n_ctx = aws_mem_calloc(alloc, 1, sizeof(struct s2n_ctx));
+
     s2n_ctx->ctx.alloc = alloc;
     s2n_ctx->ctx.impl = s2n_ctx;
     aws_ref_count_init(&s2n_ctx->ctx.ref_count, s2n_ctx, (aws_simple_completion_callback *)s_s2n_ctx_destroy);
@@ -1534,8 +1535,15 @@ static struct aws_tls_ctx *s_tls_ctx_new(
             /* No-Op, if the user configured a minimum_tls_version then a version-specific Cipher Preference was set
              */
             break;
-        case AWS_IO_TLS_CIPHER_PREF_PQ_TLSv1_0_2021_05:
-            security_policy = "PQ-TLS-1-0-2021-05-26";
+        case AWS_IO_TLS_CIPHER_PREF_PQ_DEFAULT:
+            /* The specific PQ policy used here may change over time. */
+            security_policy = "AWS-CRT-SDK-TLSv1.2-2023-PQ";
+            break;
+        case AWS_IO_TLS_CIPHER_PREF_PQ_TLSV1_2_2024_10:
+            security_policy = "AWS-CRT-SDK-TLSv1.2-2023-PQ";
+            break;
+        case AWS_IO_TLS_CIPHER_PREF_TLSV1_2_2025_07:
+            security_policy = "AWS-CRT-SDK-TLSv1.2-2025";
             break;
         default:
             AWS_LOGF_ERROR(AWS_LS_IO_TLS, "Unrecognized TLS Cipher Preference: %d", options->cipher_pref);
@@ -1544,6 +1552,14 @@ static struct aws_tls_ctx *s_tls_ctx_new(
     }
 
     AWS_ASSERT(security_policy != NULL);
+
+    AWS_LOGF_DEBUG(
+        AWS_LS_IO_TLS,
+        "Set security policy to %s (minimum_tls_version: %d; cipher_pref: %d)",
+        security_policy,
+        (int)options->minimum_tls_version,
+        (int)options->cipher_pref);
+
     if (s2n_config_set_cipher_preferences(s2n_ctx->s2n_config, security_policy)) {
         AWS_LOGF_ERROR(
             AWS_LS_IO_TLS,
@@ -1709,7 +1725,7 @@ static struct aws_tls_ctx *s_tls_ctx_new(
 
     if (options->alpn_list) {
         AWS_LOGF_DEBUG(AWS_LS_IO_TLS, "ctx: Setting ALPN list %s", aws_string_c_str(options->alpn_list));
-        const char protocols_cpy[4][128];
+        const char protocols_cpy[4][128] = {{0}};
         AWS_ZERO_ARRAY(protocols_cpy);
         size_t protocols_size = 4;
         if (s_parse_protocol_preferences(options->alpn_list, protocols_cpy, &protocols_size)) {
